useDynLib(phyclust)

import(ape)

importFrom("graphics", "abline", "axis", "barplot", "lines", "par",
           "plot", "rect")
importFrom("stats", "rmultinom")
importFrom("utils", "read.table", "write.table")

exportPattern("^[[:alpha:]]+")
# exportPattern("^[\\.]")

export(
.EMControl,
.show.option
)

S3method(print, ms)
S3method(print, phyclust)
S3method(print, Pt)
S3method(print, RRand)
S3method(print, seq.data)
S3method(print, seqgen)
S3method(print, baseml)
S3method(summary, phyclust)

S3method(acode2aid, default)
S3method(acode2aid, list)
S3method(aid2acode, default)
S3method(aid2acode, list)
S3method(cid2aid, default)
S3method(cid2aid, list)
S3method(code2nid, default)
S3method(code2nid, list)
S3method(code2snp, default)
S3method(code2snp, list)
S3method(nid2aid, default)
S3method(nid2aid, list)
S3method(nid2cid, default)
S3method(nid2cid, list)
S3method(nid2code, default)
S3method(nid2code, list)
S3method(sid2snp, default)
S3method(sid2snp, list)
S3method(snp2code, default)
S3method(snp2code, list)
S3method(snp2sid, default)
S3method(snp2sid, list)

